local internet = require('internet')

function parent(path)
    local last_slash = string.find(string.reverse(path),'/')
    if last_slash == nil then
        return false, "path '" .. path .. "' contains no '/'"
    end
    return true, string.sub(path, 1, string.len(path) - last_slash)
end

function download_file(url, path)
    local success, result = parent(path)
    if not success then
        return false, result
    end

    local success, err = filesystem.makeDirectory(result)
    if success == nil and err ~= "file or directory with that name already exists" then
        return false, err
    end

    local handle = internet.request(url)
    local safe_handle = function ()
        return pcall(handle)
    end
    local buf, err = io.open(path, 'w')
    if buf == nil then
        return false, "could not open " .. err
    end
    for success, result, test in safe_handle do
        if success then
            if result == nil then
                break
            end
            local success, write_result = pcall(buf.write, buf, result)
            if not success then
                buf:close()
                return false, "Could not write '" .. tostring(result) .. "': " .. write_result
            end
        else
            buf:close()
            return false, "Could not download file from '" .. url .. "': " .. result
        end
    end
    buf:close()
    return true
end

local success, err = download_file('https://files.sooftware.nl/replicca/rspt-repo/rspt/latest/lib/rspt.lua', '/lib/rspt.lua')
if not success then
    error(err)
end
local rspt = require('rspt')

local success, result = parent(rspt.SOURCES_FILE)
if not success then
    return false, result
end
filesystem.makeDirectory(result)

local success, err = download_file('https://files.sooftware.nl/replicca/rspt-repo/rspt/latest/etc/rspt/sources.list', rspt.SOURCES_FILE)
if not success then
    error(err)
end

local success, err = rspt.update('rspt', true)
if not success then
    error(err)
end
package.loaded.rspt = nil
require('rspt')
